Class: OMQ::ROUTER
- Defined in:
- lib/omq/router_dealer.rb
Overview
ROUTER socket.
Constant Summary
Constants included from Writable
Instance Attribute Summary
Attributes inherited from Socket
#engine, #last_tcp_port, #options
Instance Method Summary collapse
-
#initialize(endpoints = nil, linger: 0, backend: nil) ⇒ ROUTER
constructor
A new instance of ROUTER.
-
#send_to(receiver, message) ⇒ self
Sends a message to a specific peer by identity.
Methods included from Writable
Methods included from QueueWritable
Methods included from Readable
Methods included from QueueReadable
Methods inherited from Socket
#all_peers_gone, #attach_endpoints, bind, #bind, #close, #close_read, connect, #connect, #connection_count, #disconnect, #init_engine, #inspect, #last_endpoint, #monitor, #peer_connected, #reconnect_enabled=, #set_unbounded, #stop, #subscriber_joined, #unbind
Constructor Details
#initialize(endpoints = nil, linger: 0, backend: nil) ⇒ ROUTER
Returns a new instance of ROUTER.
31 32 33 34 |
# File 'lib/omq/router_dealer.rb', line 31 def initialize(endpoints = nil, linger: 0, backend: nil) init_engine(:ROUTER, linger: linger, backend: backend) attach_endpoints(endpoints, default: :bind) end |
Instance Method Details
#send_to(receiver, message) ⇒ self
Sends a message to a specific peer by identity.
43 44 45 46 |
# File 'lib/omq/router_dealer.rb', line 43 def send_to(receiver, ) parts = .is_a?(Array) ? : [] send([receiver, '', *parts]) end |